@@ -2,9 +2,7 @@
 use strict;
 use warnings;
 use lib './lib';
-use Class::STL::Containers;
-use Class::STL::Algorithms;
-use Class::STL::Utilities;
+use stl;
 
 print ">>>$0>>>>:\n";
 my $d1 = deque();
