@@ -1,10 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use lib './lib';
-use Class::STL::Containers;
-use Class::STL::Algorithms;
-use Class::STL::Utilities;
+use stl;
 
 print ">>>$0>>>\n";
 my $v = list();
@@ -38,16 +35,10 @@ for_each($v->begin(), $v->end(), MyPrint->new());
 {
 	package MyMatch;
 	use base qw(Class::STL::Utilities::FunctionObject::UnaryFunction);
-	sub BEGIN { Class::STL::DataMembers->new( qw( what ) ); }
-	sub new
-	{
-		my $self = shift;
-		my $class = ref($self) || $self;
-		$self = $class->SUPER::new(@_);
-		bless($self, $class);
-		$self->members_init(@_);
-		return $self;
-	}
+	use Class::STL::ClassMembers (
+			qw(what),
+			Class::STL::ClassMembers::FunctionMember::New->new(),
+	); 
 	sub function_operator
 	{
 		my $self = shift;
