@@ -30,8 +30,9 @@ package Class::STL::Utilities;
 require 5.005_62;
 use strict;
 use warnings;
-use vars qw( $VERSION $BUILD @EXPORT_OK %EXPORT_TAGS );
-use Exporter;
+use vars qw( $VERSION $BUILD @ISA @EXPORT_OK %EXPORT_TAGS );
+require Exporter;
+@ISA = 'Exporter';
 my @export_names = qw( 
 	equal_to not_equal_to greater greater_equal less less_equal compare bind1st bind2nd 
 	mem_fun ptr_fun ptr_fun_binary matches matches_ic logical_and logical_or 
